@@ -15,39 +15,39 @@ Usage::
 import sys
 from typing import Any, Dict, Type
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .paginator import ListBackendJobsPaginator
 from .type_defs import (
     BackendAPIResourceConfigTypeDef,
-    CloneBackendResponseResponseTypeDef,
-    CreateBackendAPIResponseResponseTypeDef,
+    CloneBackendResponseTypeDef,
+    CreateBackendAPIResponseTypeDef,
     CreateBackendAuthResourceConfigTypeDef,
-    CreateBackendAuthResponseResponseTypeDef,
-    CreateBackendConfigResponseResponseTypeDef,
-    CreateBackendResponseResponseTypeDef,
-    CreateTokenResponseResponseTypeDef,
-    DeleteBackendAPIResponseResponseTypeDef,
-    DeleteBackendAuthResponseResponseTypeDef,
-    DeleteBackendResponseResponseTypeDef,
-    DeleteTokenResponseResponseTypeDef,
-    GenerateBackendAPIModelsResponseResponseTypeDef,
-    GetBackendAPIModelsResponseResponseTypeDef,
-    GetBackendAPIResponseResponseTypeDef,
-    GetBackendAuthResponseResponseTypeDef,
-    GetBackendJobResponseResponseTypeDef,
-    GetBackendResponseResponseTypeDef,
-    GetTokenResponseResponseTypeDef,
-    ImportBackendAuthResponseResponseTypeDef,
-    ListBackendJobsResponseResponseTypeDef,
+    CreateBackendAuthResponseTypeDef,
+    CreateBackendConfigResponseTypeDef,
+    CreateBackendResponseTypeDef,
+    CreateTokenResponseTypeDef,
+    DeleteBackendAPIResponseTypeDef,
+    DeleteBackendAuthResponseTypeDef,
+    DeleteBackendResponseTypeDef,
+    DeleteTokenResponseTypeDef,
+    GenerateBackendAPIModelsResponseTypeDef,
+    GetBackendAPIModelsResponseTypeDef,
+    GetBackendAPIResponseTypeDef,
+    GetBackendAuthResponseTypeDef,
+    GetBackendJobResponseTypeDef,
+    GetBackendResponseTypeDef,
+    GetTokenResponseTypeDef,
+    ImportBackendAuthResponseTypeDef,
+    ListBackendJobsResponseTypeDef,
     LoginAuthConfigReqObjTypeDef,
-    RemoveAllBackendsResponseResponseTypeDef,
-    RemoveBackendConfigResponseResponseTypeDef,
-    UpdateBackendAPIResponseResponseTypeDef,
+    RemoveAllBackendsResponseTypeDef,
+    RemoveBackendConfigResponseTypeDef,
+    UpdateBackendAPIResponseTypeDef,
     UpdateBackendAuthResourceConfigTypeDef,
-    UpdateBackendAuthResponseResponseTypeDef,
-    UpdateBackendConfigResponseResponseTypeDef,
-    UpdateBackendJobResponseResponseTypeDef,
+    UpdateBackendAuthResponseTypeDef,
+    UpdateBackendConfigResponseTypeDef,
+    UpdateBackendJobResponseTypeDef,
 )
 
 if sys.version_info >= (3, 8):
@@ -75,30 +75,35 @@ class Exceptions:
     TooManyRequestsException: Type[BotocoreClientError]
 
 
-class AmplifyBackendClient:
+class AmplifyBackendClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        AmplifyBackendClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#can_paginate)
         """
 
     def clone_backend(
         self, *, AppId: str, BackendEnvironmentName: str, TargetEnvironmentName: str
-    ) -> CloneBackendResponseResponseTypeDef:
+    ) -> CloneBackendResponseTypeDef:
         """
         This operation clones an existing backend.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.clone_backend)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.clone_backend)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#clone_backend)
         """
 
@@ -110,11 +115,11 @@ class AmplifyBackendClient:
         BackendEnvironmentName: str,
         ResourceConfig: Dict[str, Any] = None,
         ResourceName: str = None
-    ) -> CreateBackendResponseResponseTypeDef:
+    ) -> CreateBackendResponseTypeDef:
         """
         This operation creates a backend for an Amplify app.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#create_backend)
         """
 
@@ -125,11 +130,11 @@ class AmplifyBackendClient:
         BackendEnvironmentName: str,
         ResourceConfig: "BackendAPIResourceConfigTypeDef",
         ResourceName: str
-    ) -> CreateBackendAPIResponseResponseTypeDef:
+    ) -> CreateBackendAPIResponseTypeDef:
         """
         Creates a new backend API resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_api)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_api)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#create_backend_api)
         """
 
@@ -140,40 +145,40 @@ class AmplifyBackendClient:
         BackendEnvironmentName: str,
         ResourceConfig: "CreateBackendAuthResourceConfigTypeDef",
         ResourceName: str
-    ) -> CreateBackendAuthResponseResponseTypeDef:
+    ) -> CreateBackendAuthResponseTypeDef:
         """
         Creates a new backend authentication resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_auth)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_auth)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#create_backend_auth)
         """
 
     def create_backend_config(
         self, *, AppId: str, BackendManagerAppId: str = None
-    ) -> CreateBackendConfigResponseResponseTypeDef:
+    ) -> CreateBackendConfigResponseTypeDef:
         """
         Creates a config object for a backend.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#create_backend_config)
         """
 
-    def create_token(self, *, AppId: str) -> CreateTokenResponseResponseTypeDef:
+    def create_token(self, *, AppId: str) -> CreateTokenResponseTypeDef:
         """
         Generates a one-time challenge code to authenticate a user into your Amplify
         Admin UI.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.create_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.create_token)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#create_token)
         """
 
     def delete_backend(
         self, *, AppId: str, BackendEnvironmentName: str
-    ) -> DeleteBackendResponseResponseTypeDef:
+    ) -> DeleteBackendResponseTypeDef:
         """
         Removes an existing environment from your Amplify project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#delete_backend)
         """
 
@@ -184,39 +189,39 @@ class AmplifyBackendClient:
         BackendEnvironmentName: str,
         ResourceName: str,
         ResourceConfig: "BackendAPIResourceConfigTypeDef" = None
-    ) -> DeleteBackendAPIResponseResponseTypeDef:
+    ) -> DeleteBackendAPIResponseTypeDef:
         """
         Deletes an existing backend API resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend_api)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend_api)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#delete_backend_api)
         """
 
     def delete_backend_auth(
         self, *, AppId: str, BackendEnvironmentName: str, ResourceName: str
-    ) -> DeleteBackendAuthResponseResponseTypeDef:
+    ) -> DeleteBackendAuthResponseTypeDef:
         """
         Deletes an existing backend authentication resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend_auth)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend_auth)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#delete_backend_auth)
         """
 
-    def delete_token(self, *, AppId: str, SessionId: str) -> DeleteTokenResponseResponseTypeDef:
+    def delete_token(self, *, AppId: str, SessionId: str) -> DeleteTokenResponseTypeDef:
         """
         Deletes the challenge token based on the given appId and sessionId.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_token)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#delete_token)
         """
 
     def generate_backend_api_models(
         self, *, AppId: str, BackendEnvironmentName: str, ResourceName: str
-    ) -> GenerateBackendAPIModelsResponseResponseTypeDef:
+    ) -> GenerateBackendAPIModelsResponseTypeDef:
         """
         Generates a model schema for an existing backend API resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.generate_backend_api_models)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.generate_backend_api_models)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#generate_backend_api_models)
         """
 
@@ -230,17 +235,17 @@ class AmplifyBackendClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#generate_presigned_url)
         """
 
     def get_backend(
         self, *, AppId: str, BackendEnvironmentName: str = None
-    ) -> GetBackendResponseResponseTypeDef:
+    ) -> GetBackendResponseTypeDef:
         """
         Provides project-level details for your Amplify UI project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#get_backend)
         """
 
@@ -251,49 +256,49 @@ class AmplifyBackendClient:
         BackendEnvironmentName: str,
         ResourceName: str,
         ResourceConfig: "BackendAPIResourceConfigTypeDef" = None
-    ) -> GetBackendAPIResponseResponseTypeDef:
+    ) -> GetBackendAPIResponseTypeDef:
         """
         Gets the details for a backend API.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_api)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_api)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#get_backend_api)
         """
 
     def get_backend_api_models(
         self, *, AppId: str, BackendEnvironmentName: str, ResourceName: str
-    ) -> GetBackendAPIModelsResponseResponseTypeDef:
+    ) -> GetBackendAPIModelsResponseTypeDef:
         """
         Generates a model schema for existing backend API resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_api_models)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_api_models)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#get_backend_api_models)
         """
 
     def get_backend_auth(
         self, *, AppId: str, BackendEnvironmentName: str, ResourceName: str
-    ) -> GetBackendAuthResponseResponseTypeDef:
+    ) -> GetBackendAuthResponseTypeDef:
         """
         Gets a backend auth details.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_auth)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_auth)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#get_backend_auth)
         """
 
     def get_backend_job(
         self, *, AppId: str, BackendEnvironmentName: str, JobId: str
-    ) -> GetBackendJobResponseResponseTypeDef:
+    ) -> GetBackendJobResponseTypeDef:
         """
         Returns information about a specific job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#get_backend_job)
         """
 
-    def get_token(self, *, AppId: str, SessionId: str) -> GetTokenResponseResponseTypeDef:
+    def get_token(self, *, AppId: str, SessionId: str) -> GetTokenResponseTypeDef:
         """
         Gets the challenge token based on the given appId and sessionId.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.get_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.get_token)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#get_token)
         """
 
@@ -306,11 +311,11 @@ class AmplifyBackendClient:
         UserPoolId: str,
         WebClientId: str,
         IdentityPoolId: str = None
-    ) -> ImportBackendAuthResponseResponseTypeDef:
+    ) -> ImportBackendAuthResponseTypeDef:
         """
         Imports an existing backend authentication resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.import_backend_auth)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.import_backend_auth)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#import_backend_auth)
         """
 
@@ -324,29 +329,29 @@ class AmplifyBackendClient:
         NextToken: str = None,
         Operation: str = None,
         Status: str = None
-    ) -> ListBackendJobsResponseResponseTypeDef:
+    ) -> ListBackendJobsResponseTypeDef:
         """
         Lists the jobs for the backend of an Amplify app.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.list_backend_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.list_backend_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#list_backend_jobs)
         """
 
     def remove_all_backends(
         self, *, AppId: str, CleanAmplifyApp: bool = None
-    ) -> RemoveAllBackendsResponseResponseTypeDef:
+    ) -> RemoveAllBackendsResponseTypeDef:
         """
         Removes all backend environments from your Amplify project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.remove_all_backends)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.remove_all_backends)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#remove_all_backends)
         """
 
-    def remove_backend_config(self, *, AppId: str) -> RemoveBackendConfigResponseResponseTypeDef:
+    def remove_backend_config(self, *, AppId: str) -> RemoveBackendConfigResponseTypeDef:
         """
         Removes the AWS resources required to access the Amplify Admin UI.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.remove_backend_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.remove_backend_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#remove_backend_config)
         """
 
@@ -357,11 +362,11 @@ class AmplifyBackendClient:
         BackendEnvironmentName: str,
         ResourceName: str,
         ResourceConfig: "BackendAPIResourceConfigTypeDef" = None
-    ) -> UpdateBackendAPIResponseResponseTypeDef:
+    ) -> UpdateBackendAPIResponseTypeDef:
         """
         Updates an existing backend API resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_api)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_api)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#update_backend_api)
         """
 
@@ -372,21 +377,21 @@ class AmplifyBackendClient:
         BackendEnvironmentName: str,
         ResourceConfig: "UpdateBackendAuthResourceConfigTypeDef",
         ResourceName: str
-    ) -> UpdateBackendAuthResponseResponseTypeDef:
+    ) -> UpdateBackendAuthResponseTypeDef:
         """
         Updates an existing backend authentication resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_auth)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_auth)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#update_backend_auth)
         """
 
     def update_backend_config(
         self, *, AppId: str, LoginAuthConfig: "LoginAuthConfigReqObjTypeDef" = None
-    ) -> UpdateBackendConfigResponseResponseTypeDef:
+    ) -> UpdateBackendConfigResponseTypeDef:
         """
         Updates the AWS resources required to access the Amplify Admin UI.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#update_backend_config)
         """
 
@@ -398,11 +403,11 @@ class AmplifyBackendClient:
         JobId: str,
         Operation: str = None,
         Status: str = None
-    ) -> UpdateBackendJobResponseResponseTypeDef:
+    ) -> UpdateBackendJobResponseTypeDef:
         """
         Updates a specific job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#update_backend_job)
         """
 
@@ -410,6 +415,6 @@ class AmplifyBackendClient:
         self, operation_name: Literal["list_backend_jobs"]
     ) -> ListBackendJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/paginators.html#listbackendjobspaginator)
         """
