@@ -22,14 +22,14 @@ from typing import Iterator
 
 from botocore.paginate import Paginator as Boto3Paginator
 
-from .type_defs import ListBackendJobsResponseResponseTypeDef, PaginatorConfigTypeDef
+from .type_defs import ListBackendJobsResponseTypeDef, PaginatorConfigTypeDef
 
 __all__ = ("ListBackendJobsPaginator",)
 
 
 class ListBackendJobsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/paginators.html#listbackendjobspaginator)
     """
 
@@ -42,8 +42,8 @@ class ListBackendJobsPaginator(Boto3Paginator):
         Operation: str = None,
         Status: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListBackendJobsResponseResponseTypeDef]:
+    ) -> Iterator[ListBackendJobsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/paginators.html#listbackendjobspaginator)
         """
